Type: Package
Package: RobinCar2
Title: ROBust INference for Covariate Adjustment in Randomized Clinical
        Trials
Version: 0.2.4
Date: 2026-08-19
Authors@R: 
    c(
      person("Liming", "Li", , "liming.li1@astrazeneca.com", role = c("aut", "cre"), comment = c(ORCID = "0009-0008-6870-0878")),
      person("Marlena", "Bannick", , "mnorwood@uw.edu", role="aut", comment=c(ORCID="0000-0001-6279-5978")),
      person("Daniel", "Sabanes Bove", , "daniel@rconis.com", role = "aut", comment = c(ORCID = "0000-0002-0176-9239")),
      person("Dong", "Xi", , "Dong.Xi1@gilead.com", role = "aut"),
      person("Ting", "Ye", , "tingye1@uw.edu", role="aut"),
      person("Yanyao", "Yi", , "yi_yanyao@lilly.com", role="aut"),
      person("Gregory", "Chen", , "xiangyi.gregory.chen@msd.com", role = "ctb"),
      person("Gilead Sciences, Inc.", role = c("cph", "fnd")),
      person("F. Hoffmann-La Roche AG", role = c("cph", "fnd")),
      person("Merck Sharp & Dohme, Inc.", role = c("cph", "fnd")),
      person("AstraZeneca plc", role = c("cph", "fnd")),
      person("Eli Lilly and Company", role = c("cph", "fnd")),
      person("Novartis Pharma AG", role = c("cph", "fnd")),
      person("The University of Washington", role = c("cph", "fnd"))
    )
Description: Performs robust estimation and inference when using covariate adjustment
  and/or covariate-adaptive randomization in randomized controlled trials.
  This package is trimmed to reduce the dependencies and validated to be used across industry.
  See "FDA's final guidance on covariate adjustment"<https://www.regulations.gov/docket/FDA-2019-D-0934>, Tsiatis (2008) <doi:10.1002/sim.3113>,
  Bugni et al. (2018) <doi:10.1080/01621459.2017.1375934>, Ye, Shao, Yi, and Zhao (2023)<doi:10.1080/01621459.2022.2049278>,
  Ye, Shao, and Yi (2022)<doi:10.1093/biomet/asab015>, Rosenblum and van der Laan (2010)<doi:10.2202/1557-4679.1138>,
  Wang et al. (2021)<doi:10.1080/01621459.2021.1981338>, Ye, Bannick, Yi, and Shao (2023)<doi:10.1080/24754269.2023.2205802>,
  and Bannick, Shao, Liu, Du, Yi, and Ye (2024)<doi:10.48550/arXiv.2306.10213>.
License: Apache License 2.0
URL: https://github.com/openpharma/RobinCar2/
BugReports: https://github.com/openpharma/RobinCar2/issues
Depends: R (>= 3.6)
Imports: checkmate, numDeriv, MASS, sandwich, stats, survival, utils
Suggests: knitr, rmarkdown, speff2trial, testthat (>= 3.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
LazyData: true
Config/roxygen2/version: 8.1.0
NeedsCompilation: no
Packaged: 2026-08-21 01:57:33 UTC; root
Author: Liming Li [aut, cre] (ORCID: <https://orcid.org/0009-0008-6870-0878>),
  Marlena Bannick [aut] (ORCID: <https://orcid.org/0000-0001-6279-5978>),
  Daniel Sabanes Bove [aut] (ORCID:
    <https://orcid.org/0000-0002-0176-9239>),
  Dong Xi [aut],
  Ting Ye [aut],
  Yanyao Yi [aut],
  Gregory Chen [ctb],
  Gilead Sciences, Inc. [cph, fnd],
  F. Hoffmann-La Roche AG [cph, fnd],
  Merck Sharp & Dohme, Inc. [cph, fnd],
  AstraZeneca plc [cph, fnd],
  Eli Lilly and Company [cph, fnd],
  Novartis Pharma AG [cph, fnd],
  The University of Washington [cph, fnd]
Maintainer: Liming Li <liming.li1@astrazeneca.com>
Repository: CRAN
Date/Publication: 2026-08-22 17:30:02 UTC
Built: R 4.5.2; ; 2026-08-22 21:01:30 UTC; unix
