# Generated by roxygen2: do not edit by hand

S3method(confint,prediction_cf)
S3method(confint,surv_effect)
S3method(confint,treatment_effect)
S3method(find_data,glm)
S3method(find_data,lm)
S3method(predict_counterfactual,glm)
S3method(predict_counterfactual,lm)
S3method(print,prediction_cf)
S3method(print,robin_output)
S3method(print,surv_effect)
S3method(print,treatment_effect)
S3method(table,default)
S3method(table,surv_effect)
S3method(treatment_effect,glm)
S3method(treatment_effect,lm)
S3method(treatment_effect,prediction_cf)
export(against_ref)
export(custom_contrast)
export(eff_jacob)
export(find_data)
export(h_diff)
export(h_jac_diff)
export(h_jac_log_odds_ratio)
export(h_jac_log_risk_ratio)
export(h_jac_odds_ratio)
export(h_jac_risk_ratio)
export(h_log_odds_ratio)
export(h_log_risk_ratio)
export(h_odds_ratio)
export(h_risk_ratio)
export(pairwise)
export(predict_counterfactual)
export(robin_glm)
export(robin_lm)
export(robin_surv)
export(surv_control)
export(table)
export(treatment_effect)
export(vcovG)
export(vcovHC)
import(checkmate)
importFrom(MASS,negative.binomial)
importFrom(numDeriv,grad)
importFrom(sandwich,vcovHC)
importFrom(stats,as.formula)
importFrom(stats,coefficients)
importFrom(stats,confint)
importFrom(stats,family)
importFrom(stats,fitted)
importFrom(stats,gaussian)
importFrom(stats,glm)
importFrom(stats,lm)
importFrom(stats,model.matrix)
importFrom(stats,model.response)
importFrom(stats,pnorm)
importFrom(stats,predict)
importFrom(stats,qnorm)
importFrom(stats,residuals)
importFrom(stats,terms)
importFrom(stats,var)
importFrom(utils,combn)
importFrom(utils,tail)
