# h_get_lm_results works as expected

    list(beta_est = list(A = c(covariate1 = 0.124630109689139, covariate2 = 0.417147008547665
    ), B = c(covariate1 = 1.8889272308284, covariate2 = -0.824394901815606
    )), residuals = list(A = c("1" = 0.328159679550758, "2" = 0.784356412897211, 
    "4" = -0.487223558432553, "7" = 0.179869428929531, "8" = -0.237599941348964, 
    "9" = -0.567562021595984), B = c("3" = 0.207437533059178, "5" = 0.00713842971687903, 
    "6" = -0.185427485486945, "10" = -0.029148477289112)))

# h_get_strat_lm_results works as expected

    WAoAAAACAAQFAgACAwAAAAITAAAAAgAAAhMAAAACAAACDgAAAAI/2EodY7qjWT/Yhf+la9RI
    AAAEAgAAAAEABAAJAAAAA2RpbQAAAA0AAAACAAAAAgAAAAEAAAQCAAAAAQAEAAkAAAAIZGlt
    bmFtZXMAAAATAAAAAgAAABAAAAACAAQACQAAAApjb3ZhcmlhdGUxAAQACQAAAApjb3Zhcmlh
    dGUyAAAA/gAAAP4AAAIOAAAAAj/wvxc1pMcSv+gFJa7236oAAAQCAAAB/wAAAA0AAAACAAAA
    AgAAAAEAAAQCAAAC/wAAABMAAAACAAAAEAAAAAIABAAJAAAACmNvdmFyaWF0ZTEABAAJAAAA
    CmNvdmFyaWF0ZTIAAAD+AAAA/gAABAIAAAABAAQACQAAAAVuYW1lcwAAABAAAAACAAQACQAA
    AAFBAAQACQAAAAFCAAAA/gAAAhMAAAACAAACDgAAAAu/tDGyIAgxfD/wKxLtnpFov9+JqMTO
    xPI/xSMSkMK6bL+ZG5UDNbOgv+KLAzDruyY/+de0QI9Snz/aaNrYVMlYv+GJ39s2z2y/7CFQ
    4UUqQr/jOKUwzRA8AAAEAgAAA/8AAAAQAAAACwAEAAkAAAABMQAEAAkAAAABMgAEAAkAAAAB
    NAAEAAkAAAABNwAEAAkAAAABOAAEAAkAAAABOQAEAAkAAAACMTEABAAJAAAAAjEyAAQACQAA
    AAIxNgAEAAkAAAACMTcABAAJAAAAAjE5AAAA/gAAAg4AAAAJP9HKSfx49fo/yoMS8V3yML+g
    fiRxSj28v9z8Dub+p1w/92hRkoZfVL/3wer7XqF6P+glamCsz02/qszDp4CpqL/lxWtUhEBs
    AAAEAgAAA/8AAAAQAAAACQAEAAkAAAABMwAEAAkAAAABNQAEAAkAAAABNgAEAAkAAAACMTAA
    BAAJAAAAAjEzAAQACQAAAAIxNAAEAAkAAAACMTUABAAJAAAAAjE4AAQACQAAAAIyMAAAAP4A
    AAQCAAAD/wAAABAAAAACAAQACQAAAAFBAAQACQAAAAFCAAAA/gAABAIAAAP/AAAAEAAAAAIA
    BAAJAAAACGJldGFfZXN0AAQACQAAAAlyZXNpZHVhbHMAAAD+

