% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{randomization_schema}
\alias{randomization_schema}
\title{Randomization schema}
\usage{
randomization_schema
}
\description{
Randomization schema
}
\keyword{internal}
