% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{jac_mat}
\alias{jac_mat}
\title{Obtain the Jacobian matrix}
\usage{
jac_mat(jac, pair)
}
\description{
Obtain the Jacobian matrix
}
\keyword{internal}
