% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{block_sum}
\alias{block_sum}
\title{Block Sum of a matrix}
\usage{
block_sum(x, n)
}
\description{
Block Sum of a matrix
}
\keyword{internal}
