% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{update_levels}
\alias{update_levels}
\title{Update levels in a contrast pair}
\usage{
update_levels(pair, levels)
}
\description{
Update levels in a contrast pair
}
\keyword{internal}
