% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{surv_data}
\alias{surv_data}
\title{Survival Example Data}
\format{
An object of class \code{data.frame} with 228 rows and 12 columns.
}
\source{
The data is generated by the \code{create_surv_data.R} script.
}
\usage{
surv_data
}
\description{
This dataset contains survival data from the \code{survival}
package's \link[survival:lung]{survival::lung} dataset, modified to include factors for
\code{sex} and \code{strata}, as well as a binary \code{status} variable which is 1
for death and 0 for censored.
}
\keyword{dataset}
