% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{sum_vectors_in_list}
\alias{sum_vectors_in_list}
\title{Sum vectors in a list}
\usage{
sum_vectors_in_list(lst)
}
\description{
Sum vectors in a list
}
\keyword{internal}
